@@ -22,6 +22,8 @@ class INotify(object):
 
     def __cb_handler(self, s):
         wd = s[0]
+        if wd not in self.__files:
+            return
         path = self.__files[wd]
         self.__cb(path)
         if s[1] == 2048:
